==> android-4.0.1.2-sources.jar: android/view/ViewConfiguration.java <==
package android.view;
public class ViewConfiguration
{
public  ViewConfiguration() { throw new RuntimeException("Stub!"); }
public static  android.view.ViewConfiguration get(android.content.Context context) { throw new RuntimeException("Stub!"); }
public static  int getScrollBarSize() { throw new RuntimeException("Stub!"); }
public  int getScaledScrollBarSize() { throw new RuntimeException("Stub!"); }
public static  int getScrollBarFadeDuration() { throw new RuntimeException("Stub!"); }
public static  int getScrollDefaultDelay() { throw new RuntimeException("Stub!"); }
public static  int getFadingEdgeLength() { throw new RuntimeException("Stub!"); }
public  int getScaledFadingEdgeLength() { throw new RuntimeException("Stub!"); }
public static  int getPressedStateDuration() { throw new RuntimeException("Stub!"); }
public static  int getLongPressTimeout() { throw new RuntimeException("Stub!"); }
public static  int getKeyRepeatTimeout() { throw new RuntimeException("Stub!"); }
public static  int getKeyRepeatDelay() { throw new RuntimeException("Stub!"); }
public static  int getTapTimeout() { throw new RuntimeException("Stub!"); }
public static  int getJumpTapTimeout() { throw new RuntimeException("Stub!"); }
public static  int getDoubleTapTimeout() { throw new RuntimeException("Stub!"); }
public static  int getEdgeSlop() { throw new RuntimeException("Stub!"); }
public  int getScaledEdgeSlop() { throw new RuntimeException("Stub!"); }
public static  int getTouchSlop() { throw new RuntimeException("Stub!"); }
public  int getScaledTouchSlop() { throw new RuntimeException("Stub!"); }
public  int getScaledPagingTouchSlop() { throw new RuntimeException("Stub!"); }
public  int getScaledDoubleTapSlop() { throw new RuntimeException("Stub!"); }
public static  int getWindowTouchSlop() { throw new RuntimeException("Stub!"); }
public  int getScaledWindowTouchSlop() { throw new RuntimeException("Stub!"); }
public static  int getMinimumFlingVelocity() { throw new RuntimeException("Stub!"); }
public  int getScaledMinimumFlingVelocity() { throw new RuntimeException("Stub!"); }
public static  int getMaximumFlingVelocity() { throw new RuntimeException("Stub!"); }
public  int getScaledMaximumFlingVelocity() { throw new RuntimeException("Stub!"); }
public static  int getMaximumDrawingCacheSize() { throw new RuntimeException("Stub!"); }
public  int getScaledMaximumDrawingCacheSize() { throw new RuntimeException("Stub!"); }
public  int getScaledOverscrollDistance() { throw new RuntimeException("Stub!"); }
public  int getScaledOverflingDistance() { throw new RuntimeException("Stub!"); }
public static  long getZoomControlsTimeout() { throw new RuntimeException("Stub!"); }
public static  long getGlobalActionKeyTimeout() { throw new RuntimeException("Stub!"); }
public static  float getScrollFriction() { throw new RuntimeException("Stub!"); }
public  boolean hasPermanentMenuKey() { throw new RuntimeException("Stub!"); }
}

==> android-4.1.1.4-sources.jar: android/view/ViewConfiguration.java <==
package android.view;
public class ViewConfiguration
{
@java.lang.Deprecated()
public  ViewConfiguration() { throw new RuntimeException("Stub!"); }
public static  android.view.ViewConfiguration get(android.content.Context context) { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int getScrollBarSize() { throw new RuntimeException("Stub!"); }
public  int getScaledScrollBarSize() { throw new RuntimeException("Stub!"); }
public static  int getScrollBarFadeDuration() { throw new RuntimeException("Stub!"); }
public static  int getScrollDefaultDelay() { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int getFadingEdgeLength() { throw new RuntimeException("Stub!"); }
public  int getScaledFadingEdgeLength() { throw new RuntimeException("Stub!"); }
public static  int getPressedStateDuration() { throw new RuntimeException("Stub!"); }
public static  int getLongPressTimeout() { throw new RuntimeException("Stub!"); }
public static  int getKeyRepeatTimeout() { throw new RuntimeException("Stub!"); }
public static  int getKeyRepeatDelay() { throw new RuntimeException("Stub!"); }
public static  int getTapTimeout() { throw new RuntimeException("Stub!"); }
public static  int getJumpTapTimeout() { throw new RuntimeException("Stub!"); }
public static  int getDoubleTapTimeout() { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int getEdgeSlop() { throw new RuntimeException("Stub!"); }
public  int getScaledEdgeSlop() { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int getTouchSlop() { throw new RuntimeException("Stub!"); }
public  int getScaledTouchSlop() { throw new RuntimeException("Stub!"); }
public  int getScaledPagingTouchSlop() { throw new RuntimeException("Stub!"); }
public  int getScaledDoubleTapSlop() { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int getWindowTouchSlop() { throw new RuntimeException("Stub!"); }
public  int getScaledWindowTouchSlop() { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int getMinimumFlingVelocity() { throw new RuntimeException("Stub!"); }
public  int getScaledMinimumFlingVelocity() { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int getMaximumFlingVelocity() { throw new RuntimeException("Stub!"); }
public  int getScaledMaximumFlingVelocity() { throw new RuntimeException("Stub!"); }
@java.lang.Deprecated()
public static  int getMaximumDrawingCacheSize() { throw new RuntimeException("Stub!"); }
public  int getScaledMaximumDrawingCacheSize() { throw new RuntimeException("Stub!"); }
public  int getScaledOverscrollDistance() { throw new RuntimeException("Stub!"); }
public  int getScaledOverflingDistance() { throw new RuntimeException("Stub!"); }
public static  long getZoomControlsTimeout() { throw new RuntimeException("Stub!"); }
public static  long getGlobalActionKeyTimeout() { throw new RuntimeException("Stub!"); }
public static  float getScrollFriction() { throw new RuntimeException("Stub!"); }
public  boolean hasPermanentMenuKey() { throw new RuntimeException("Stub!"); }
}
